# mojave
## Tooig Operating System

Mojave is an architecture designed stritly to deliver on automation. 

We designed it to help manage certain backend functions that will bug the process of software and operations at Tooig in the future. it is also versatile enough that it can be used to develop other smaller variants.

Our first instance of a small variant is Genie. So far we've completed the build but we still need to run tests.

## Distillation 

We have a plan to distill the function of Mojave to smaller models, and use them for several uses.